<?php

namespace Drupal\file_sync;

/**
 * Defines batch service interface.
 */
interface BatchInterface {

  /**
   * Create batch.
   *
   * @param int $batch_size
   *   Batch size.
   * @param array $params
   *   Additional batch parameters.
   */
  public function create(int $batch_size, array $params = []): void;

  /**
   * Batch operation callback.
   *
   * @param array $batch
   *   Information about batch (items, size, total, ...).
   * @param array $context
   *   Batch context.
   */
  public static function process(array $batch, array &$context): void;

  /**
   * Bach operations 'finished' callback.
   *
   * @param bool $success
   *   TRUE if processing was successfully completed.
   * @param mixed $results
   *   Additional data passed from $context['results'].
   * @param array $operations
   *   List of operations that did not complete.
   */
  public static function finishProcess($success, $results, array $operations): void;

}
